<?php
/**
 * Cooking Food Blogger Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Cooking Food Blogger
 */

use WPTRT\Customize\Section\Cooking_Food_Blogger_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Cooking_Food_Blogger_Button::class );

    $manager->add_section(
        new Cooking_Food_Blogger_Button( $manager, 'cooking_food_blogger_pro', [
            'title'       => __( 'Food Blogger Pro', 'cooking-food-blogger' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'cooking-food-blogger' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/cooking-wordpress-theme/', 'cooking-food-blogger')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'cooking-food-blogger-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'cooking-food-blogger-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function cooking_food_blogger_customize_register($wp_customize){
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    //Header
    $wp_customize->add_section('cooking_food_blogger_header',array(
        'title' => esc_html__('Header Option','cooking-food-blogger')
    ));

    $wp_customize->add_setting('cooking_food_blogger_header_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_header_text',array(
        'label' => esc_html__('Header Text','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_header_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_opening_date',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_opening_date',array(
        'label' => esc_html__('Classes Date','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_opening_date',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_email',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_email'
    ));
    $wp_customize->add_control('cooking_food_blogger_email',array(
        'label' => esc_html__('Email Address','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_email',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_phone_number',array(
        'default' => '',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_phone_number'
    ));
    $wp_customize->add_control('cooking_food_blogger_phone_number',array(
        'label' => esc_html__('Phone Number','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_phone_number',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_button_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_button_text',array(
        'label' => esc_html__('Button Text','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_button_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_button_link',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_button_link',array(
        'label' => esc_html__('Button Url','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_button_link',
        'type'  => 'text'
    ));

    // Slider
    $wp_customize->add_section('cooking_food_blogger_top_slider',array(
        'title' => esc_html__('Slider Option','cooking-food-blogger')
    ));

    for ( $count = 1; $count <= 3; $count++ ) {
        $wp_customize->add_setting( 'cooking_food_blogger_top_slider_page' . $count, array(
            'default'           => '',
            'sanitize_callback' => 'cooking_food_blogger_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'cooking_food_blogger_top_slider_page' . $count, array(
            'label'    => __( 'Select Slide Page', 'cooking-food-blogger' ),
            'section'  => 'cooking_food_blogger_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    $wp_customize->add_setting('cooking_food_blogger_slider_video',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_slider_video',array(
        'label' => esc_html__('Add YouTube Embeded Link','cooking-food-blogger'),
        'description' => esc_html__('ex: https://www.youtube.com/embed/OrW7tnyZD4Q','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_slider_video',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_facebook_url',array(
        'label' => esc_html__('Facebook Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_twitter_url',array(
        'label' => esc_html__('Twitter Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_intagram_url',array(
        'label' => esc_html__('Intagram Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_youtube_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_youtube_url',array(
        'label' => esc_html__('YouTube Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_pintrest_url',
        'type'  => 'url'
    ));

    // Our Services
    $wp_customize->add_section('cooking_food_blogger_services_section',array(
        'title' => esc_html__('Our Services','cooking-food-blogger'),
        'description' => esc_html__('Here you have to select category which will display perticular services in the home page.','cooking-food-blogger')
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_short_heading',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_short_heading',array(
        'label' => esc_html__('Short Heading','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_short_heading',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_long_heading',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_long_heading',array(
        'label' => esc_html__('Main Heading','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_long_heading',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_button_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_button_text',array(
        'label' => esc_html__('Button Text','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_button_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_button_url',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_button_url',array(
        'label' => esc_html__('Button URL','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_button_url',
        'type'  => 'text'
    ));

    $categories = get_categories();
    $cat_post = array();
    $cat_post[]= 'select';
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cat_post[$category->slug] = $category->name;
    }

    $wp_customize->add_setting('cooking_food_blogger_services_sec_category',array(
        'default'   => 'select',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_select',
    ));
    $wp_customize->add_control('cooking_food_blogger_services_sec_category',array(
        'type'    => 'select',
        'choices' => $cat_post,
        'label' => __('Select Category to display services','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
    ));

    // Footer
    $wp_customize->add_section('cooking_food_blogger_site_footer_section', array(
        'title' => esc_html__('Footer', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('cooking_food_blogger_footer_text_setting', array(
        'label' => __('Replace the footer text', 'cooking-food-blogger'),
        'section' => 'cooking_food_blogger_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));
}
add_action('customize_register', 'cooking_food_blogger_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function cooking_food_blogger_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function cooking_food_blogger_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function cooking_food_blogger_customize_preview_js(){
    wp_enqueue_script('cooking-food-blogger-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'cooking_food_blogger_customize_preview_js');